searchData={"items":[{"type":"module","title":"ExRTP.Packet","doc":"RTP packet encoding and decoding functionalities.","ref":"ExRTP.Packet.html"},{"type":"module","title":"Examples - ExRTP.Packet","doc":"```elixir\n  iex> alias ExRTP.Packet\n  iex> alias ExRTP.Packet.Extension.AudioLevelExtension\n  iex> extension = AudioLevelExtension.new(true, 120) |> AudioLevelExtension.to_raw(5)\n  iex> payload =  >\n  iex> encoded =\n  ...>   payload\n  ...>   |> Packet.new(120, 50_000, 1_000_000, 500_000)\n  ...>   |> Packet.set_extension(:one_byte, [extension])\n  ...>   |> Packet.encode()\n  iex> {:ok, %Packet{payload:  >}} = Packet.decode(encoded)\n  ```","ref":"ExRTP.Packet.html#module-examples"},{"type":"function","title":"ExRTP.Packet.decode/1","doc":"Decodes binary into an RTP packet.\n\nIf packet is too short to ba valid, this function\nwill fail with `:not_enough_data` error.","ref":"ExRTP.Packet.html#decode/1"},{"type":"function","title":"ExRTP.Packet.encode/1","doc":"Encodes an RTP packet and returns resulting binary.","ref":"ExRTP.Packet.html#encode/1"},{"type":"function","title":"ExRTP.Packet.fetch_extension/2","doc":"Fetch extension with specified `id`.\n\nIf no extension with `id` is found, `:error` is returned.","ref":"ExRTP.Packet.html#fetch_extension/2"},{"type":"function","title":"ExRTP.Packet.new/6","doc":"Create new `t:ExRTP.Packet.t/0` struct.\n\nOptions:\n  * `csrc` - CSRC list, by default `[]`, must be shorter than 16, otherwise function will raise\n  * `marker` - if marker field is set, by default `false`\n  * `padding` - length of payload padding, by default no padding is added","ref":"ExRTP.Packet.html#new/6"},{"type":"function","title":"ExRTP.Packet.set_extension/3","doc":"Specify extension profile and add header extensions to the packet.\n\nIf extensions were set previously, this function will override them.\nIf profile is not one-byte or two-byte profile, `extension` should contain only one element.\n\nFunction will raise if extension format is invalid.","ref":"ExRTP.Packet.html#set_extension/3"},{"type":"type","title":"ExRTP.Packet.t/0","doc":"Struct representing an RTP packet.","ref":"ExRTP.Packet.html#t:t/0"},{"type":"type","title":"ExRTP.Packet.uint7/0","doc":"","ref":"ExRTP.Packet.html#t:uint7/0"},{"type":"type","title":"ExRTP.Packet.uint8/0","doc":"","ref":"ExRTP.Packet.html#t:uint8/0"},{"type":"type","title":"ExRTP.Packet.uint16/0","doc":"","ref":"ExRTP.Packet.html#t:uint16/0"},{"type":"type","title":"ExRTP.Packet.uint32/0","doc":"","ref":"ExRTP.Packet.html#t:uint32/0"},{"type":"behaviour","title":"ExRTP.Packet.Extension","doc":"RTP header extension functionalities.","ref":"ExRTP.Packet.Extension.html"},{"type":"callback","title":"ExRTP.Packet.Extension.from_raw/1","doc":"Converts raw extension to extension struct.","ref":"ExRTP.Packet.Extension.html#c:from_raw/1"},{"type":"function","title":"ExRTP.Packet.Extension.new/2","doc":"Create new `t:ExRTP.Packet.Extension.t/0` struct.","ref":"ExRTP.Packet.Extension.html#new/2"},{"type":"callback","title":"ExRTP.Packet.Extension.to_raw/2","doc":"Converts extension struct to raw extension which can be used\nin `ExRTP.Packet.set_extension/3`.","ref":"ExRTP.Packet.Extension.html#c:to_raw/2"},{"type":"type","title":"ExRTP.Packet.Extension.t/0","doc":"Struct representing raw RTP header extension.\n\nCan be either:\n  * header extension, as specified in `RFC 3550`, then `id` is equal to `nil`\n  * one-byte or two-byte extension, as specified in `RFC 5285`","ref":"ExRTP.Packet.Extension.html#t:t/0"},{"type":"module","title":"ExRTP.Packet.Extension.AudioLevelExtension","doc":"Audio Level Extension described in `RFC 6464`.","ref":"ExRTP.Packet.Extension.AudioLevelExtension.html"},{"type":"function","title":"ExRTP.Packet.Extension.AudioLevelExtension.new/2","doc":"Create new `t:ExRTP.Packet.Extension.AudioLevelExtension.t/0` struct.","ref":"ExRTP.Packet.Extension.AudioLevelExtension.html#new/2"},{"type":"type","title":"ExRTP.Packet.Extension.AudioLevelExtension.level/0","doc":"","ref":"ExRTP.Packet.Extension.AudioLevelExtension.html#t:level/0"},{"type":"type","title":"ExRTP.Packet.Extension.AudioLevelExtension.t/0","doc":"Struct representing Audio Level Extension.","ref":"ExRTP.Packet.Extension.AudioLevelExtension.html#t:t/0"},{"type":"extras","title":"ExRTP","doc":"# ExRTP\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_rtp.svg)](https://hex.pm/packages/ex_rtp)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/ex_rtp)\n[![CI](https://img.shields.io/github/actions/workflow/status/elixir-webrtc/ex_rtp/ci.yml?logo=github&label=CI)](https://github.com/elixir-webrtc/ex_rtp/actions/workflows/ci.yml)\n[![codecov](https://codecov.io/gh/elixir-webrtc/ex_rtp/graph/badge.svg?token=E98NHC8B00)](https://codecov.io/gh/elixir-webrtc/ex_rtp)\n\nImplementation of RTP protocol in Elixir. \n\nImplements:\n- [RFC 3550 - RTP: A Transport Protocol for Real-Time Applications](https://datatracker.ietf.org/doc/html/rfc3550)\n- [RFC 5285 - A General Mechanism for RTP Header Extensions](https://datatracker.ietf.org/doc/html/rfc5285)","ref":"readme.html"},{"type":"extras","title":"Installation - ExRTP","doc":"```elixir\ndef deps do\n  [\n    {:ex_rtp, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"}],"content_type":"text/markdown"}